@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2015-11-17'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-11-19'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -791,6 +791,28 @@ sub _complete_item {
     );
 }
 
+my $_alias_spec_add_dataset = {
+    summary => 'Add a dataset',
+    code => sub {
+        require JSON;
+
+        my $args = shift;
+        push @{ $args->{datasets} },
+            JSON::decode_json($_[0]);
+    },
+};
+
+my $_alias_spec_add_participant = {
+    summary => 'Add a participant',
+    code => sub {
+        require JSON;
+
+        my $args = shift;
+        push @{ $args->{participants} },
+            JSON::decode_json($_[0]);
+    },
+};
+
 $SPEC{bencher} = {
     v => 1.1,
     summary => 'A benchmark framework',
@@ -829,16 +851,8 @@ _
             'x.name.is_plural' => 1,
             schema => ['array*', of=>'hash*'],
             cmdline_aliases => {
-                p => {
-                    summary => 'Add a participant',
-                    code => sub {
-                        require JSON;
-
-                        my $args = shift;
-                        push @{ $args->{participants} },
-                            JSON::decode_json($_[0]);
-                    },
-                }
+                participant => $_alias_spec_add_participant,
+                p => $_alias_spec_add_participant,
             },
         },
         datasets => {
@@ -846,16 +860,8 @@ _
             'x.name.is_plural' => 1,
             schema => ['array*', of=>'hash*'],
             cmdline_aliases => {
-                d => {
-                    summary => 'Add a dataset',
-                    code => sub {
-                        require JSON;
-
-                        my $args = shift;
-                        push @{ $args->{datasets} },
-                            JSON::decode_json($_[0]);
-                    },
-                },
+                dataset => $_alias_spec_add_dataset,
+                d => $_alias_spec_add_dataset,
             },
         },
         action => {
@@ -1253,8 +1259,16 @@ sub bencher {
     }
 
     if ($action eq 'bench') {
+        my $return_resmeta =
+            $args{-cmdline_r} && (($args{-cmdline_r}{format} // '') !~ /json/) ?
+            0 : 1;
+
         require Benchmark::Dumb;
+        require Devel::Platform::Info if $return_resmeta;
         require Module::Load;
+        require Sys::Load if $return_resmeta;
+
+        my $envres = [200, "OK", [], {}];
 
         # load all modules
         {
@@ -1283,6 +1297,10 @@ sub bencher {
             $items = $fitems;
         }
 
+        if ($return_resmeta) {
+            $envres->[3]{'func.sysload_before'} = [Sys::Load::getload()];
+        }
+
         my $tres = Benchmark::Dumb::_timethese_guts(
             0,
             {
@@ -1291,7 +1309,6 @@ sub bencher {
             "silent",
         );
 
-        my $envres = [200, "OK", []];
         for my $seq (sort {$a<=>$b} keys %$tres) {
             my $it = _find_record_by_seq($items, $seq);
             push @{$envres->[2]}, {
@@ -1359,6 +1376,12 @@ sub bencher {
 
         } # FORMAT
 
+        if ($return_resmeta) {
+            $envres->[3]{'func.sysload_after'} = [Sys::Load::getload()];
+            $envres->[3]{'func.platform_info'} =
+                Devel::Platform::Info->new->get_info;
+        }
+
         return $envres;
     }
 
@@ -1396,7 +1419,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.11 of Bencher (from Perl distribution Bencher), released on 2015-11-17.
+This document describes version 0.12 of Bencher (from Perl distribution Bencher), released on 2015-11-19.
 
 =head1 SYNOPSIS
 
